####load the required packages for Multi-linear Regression analysis####

library(phyloseq)
library(tidyverse)

###load the pd_rare.RData for multi-linear regression analysis###

load("pd_rare.RData")

###Multi-linear Regression Analysis of Serum Fatty Acids (FA)###
#First, create an object that contains both the alpha diversity and pd metadata.
#Then create a filtered version, that separates the PD and Control patients, to use
#for running the following graphs and linear models

samp_dat_wdiv <- data.frame(sample_data(pd_rare), estimate_richness(pd_rare))

PD_Only <- filter(samp_dat_wdiv, Disease=='PD')

Control_Only <- filter(samp_dat_wdiv, Disease=='Control')

#Graph how the relationship of each different serum FA looks like with Shannon 
#diversity as linear model in control vs PD patients

SFA_plot <- ggplot(samp_dat_wdiv,aes(x=SFA, y=Shannon)) +
  geom_point() +
  geom_smooth(method="lm") +
  facet_grid(.~Disease, scales = "free_x")
SFA_plot

MUFA_plot <- ggplot(samp_dat_wdiv,aes(x=MUFA, y=Shannon)) +
  geom_point() +
  geom_smooth(method="lm") +
  facet_grid(.~Disease, scales = "free_x")
MUFA_plot

PUFA_plot <- ggplot(samp_dat_wdiv,aes(x=PUFA, y=Shannon)) +
  geom_point() +
  geom_smooth(method="lm") +
  facet_grid(.~Disease, scales = "free_x")
PUFA_plot

#log10 transform the graphs above, but done separately on PD and Control patients. 
#Also, find their respective correlation

SFA_Log_PD <- ggplot(PD_Only, aes(x=SFA, y=log10(Shannon))) +
  geom_point() +
  geom_smooth(method="lm") 
cor.test(PD_Only$SFA, PD_Only$Shannon, method = "spearman", exact = FALSE)

MUFA_Log_PD <- ggplot(PD_Only, aes(x=MUFA, y=log10(Shannon))) +
  geom_point() +
  geom_smooth(method="lm")
cor.test(PD_Only$MUFA, PD_Only$Shannon, method = "spearman", exact = FALSE)

PUFA_Log_PD <- ggplot(PD_Only, aes(x=PUFA, y=log10(Shannon))) +
  geom_point() +
  geom_smooth(method="lm")
cor.test(PD_Only$PUFA, PD_Only$Shannon, method = "spearman", exact = FALSE)

SFA_Log_Contol <- ggplot(Control_Only, aes(x=SFA, y=log10(Shannon))) +
  geom_point() +
  geom_smooth(method="lm")
cor.test(Control_Only$SFA, Control_Only$Shannon, method = "spearman", exact = FALSE)

MUFA_Log_Control <- ggplot(Control_Only, aes(x=MUFA, y=log10(Shannon))) +
  geom_point() +
  geom_smooth(method="lm")
cor.test(Control_Only$MUFA, Control_Only$Shannon, method = "spearman", exact = FALSE)

PUFA_Log_Control <- ggplot(Control_Only, aes(x=PUFA, y=log10(Shannon))) +
  geom_point() +
  geom_smooth(method="lm")
cor.test(Control_Only$PUFA, Control_Only$Shannon, method = "spearman", exact = FALSE)

#linear model of the 6 graphs above (with and without log10 of Shannon) to see if
#the respective FA has a significant effect

lm_SFA <- lm(Shannon ~ SFA, data=PD_Only)
summary(lm_SFA)
lm_SFA_Log <- lm(log10(Shannon) ~ SFA, data=PD_Only)
summary(lm_SFA_Log)

lm_MUFA <- lm(Shannon ~ MUFA, data=PD_Only)
summary(lm_MUFA)
lm_MUFA_Log <- lm(log10(Shannon) ~ MUFA, data=PD_Only)
summary(lm_MUFA_Log)

lm_PUFA <- lm(Shannon ~ PUFA, data=PD_Only)
summary(lm_PUFA)
lm_PUFA_Log <- lm(log10(Shannon) ~ PUFA, data=PD_Only)
summary(lm_PUFA_Log)

lm_Control_SFA <- lm(Shannon ~ SFA, data=Control_Only)
summary(lm_Control_SFA)
lm_Control_SFA_Log <- lm(log10(Shannon) ~ SFA, data=Control_Only)
summary(lm_Control_SFA_Log)

lm_Control_MUFA <- lm(Shannon ~ MUFA, data=Control_Only)
summary(lm_Control_MUFA)
lm_Control_MUFA_Log <- lm(log10(Shannon) ~ MUFA, data=Control_Only)
summary(lm_Control_MUFA_Log)

lm_Control_PUFA <- lm(Shannon ~ PUFA, data=Control_Only)
summary(lm_Control_PUFA)
lm_Control_PUFA_Log <- lm(log10(Shannon) ~ PUFA, data=Control_Only)
summary(lm_Control_PUFA_Log)

####linear model of each serum FA####
#create a linear model on both PD and Control patients for each type of serum FA that  
#also contains Age, Sex, and Location (if they lived on a farm) as predictors 
#that can have independent effects on the Shannon Diversity (controlling for confounds)

lm_PD_Age_Sex_Farm_SFA <- lm(Shannon ~ Age+Sex+Lived_on_farm+SFA, data=PD_Only)
summary(lm_PD_Age_Sex_Farm_SFA)

lm_PD_Age_Sex_Farm_MUFA <- lm(Shannon ~ Age+Sex+Lived_on_farm+MUFA, data=PD_Only)
summary(lm_PD_Age_Sex_Farm_MUFA)

lm_PD_Age_Sex_Farm_PUFA <- lm(Shannon ~ Age+Sex+Lived_on_farm+PUFA, data=PD_Only)
summary(lm_PD_Age_Sex_Farm_PUFA)

lm_Control_Age_Sex_Farm_SFA <- lm(Shannon ~ Age+Sex+Lived_on_farm+SFA, data=Control_Only)
summary(lm_Control_Age_Sex_Farm_SFA)

lm_Control_Age_Sex_Farm_MUFA <- lm(Shannon ~ Age+Sex+Lived_on_farm+MUFA, data=Control_Only)
summary(lm_Control_Age_Sex_Farm_MUFA)

lm_Control_Age_Sex_Farm_PUFA <- lm(Shannon ~ Age+Sex+Lived_on_farm+PUFA, data=Control_Only)
summary(lm_Control_Age_Sex_Farm_PUFA)

#linear model that shows the independent effect of each type of serum FA only

lm_PD_SFA_MUFA_PUFA <- lm(Shannon ~ SFA+MUFA+PUFA, data=PD_Only)
summary(lm_PD_SFA_MUFA_PUFA)

lm_Control_SFA_MUFA_PUFA <- lm(Shannon ~ SFA+MUFA+PUFA, data=Control_Only)
summary(lm_Control_SFA_MUFA_PUFA)
?lm
#linear model that combines the Confounds with all of FA types, done in both PD
#and Control patients

lm_PD_SFA_MUFA_PUFA_Confound <- lm(Shannon ~ Age+Sex+Lived_on_farm+SFA+MUFA+PUFA, data=PD_Only)
summary(lm_PD_SFA_MUFA_PUFA_Confound)

lm_Control_SFA_MUFA_PUFA_Confound <- lm(Shannon ~ Age+Sex+Lived_on_farm+SFA+MUFA+PUFA, data=Control_Only)
summary(lm_Control_SFA_MUFA_PUFA_Confound)

###Box and Whisker plot + Stats for SFA, PUFA, and MUFA###
#Making a box and Whiskers plot to visualize the different quartiles of 
#each type of FA. Then created an object containing the stats for the
#1st, 2nd, and 3rd quartiles

FAs_Boxplot <- boxplot(samp_dat_wdiv$SFA, samp_dat_wdiv$PUFA, samp_dat_wdiv$MUFA
        , horizontal = TRUE, names = c("SFA", "PUFA", "MUFA"), las = 2)
SFA_Quartile_Stats <- quantile(samp_dat_wdiv$SFA, na.rm = TRUE, probs = c(0.25, 0.5, 0.75))
PUFA_Quartile_Stats <- quantile(samp_dat_wdiv$PUFA, na.rm = TRUE, probs = c(0.25, 0.5, 0.75))
MUFA_Quartile_Stats <- quantile(samp_dat_wdiv$MUFA, na.rm = TRUE, probs = c(0.25, 0.5, 0.75))
FAs_Quartile_Stats <- data.frame(SFA_Stat=c(SFA_Quartile_Stats), 
                  PUFA_Stat=c(PUFA_Quartile_Stats), MUFA_Stat=c(MUFA_Quartile_Stats))

####Binning each FA group into high and low####

#Group each patient for each FA category into high or low groups based on
#the box plot 0.25 and 0.75 quartile results (low<0.25 quartile, high>0.75 quartile,
#0.25 quartile<=medium<=0.75 quartile).

Binned_SFA <- data.frame('SFA' = samp_dat_wdiv$SFA, 
  'Binned_SFA' = cut(samp_dat_wdiv$SFA, breaks = c(0, 17.79999, 29.9, Inf), 
   labels = c("Low", "Medium", "High"), include.lowest = TRUE))

Binned_MUFA <- data.frame('MUFA' = samp_dat_wdiv$MUFA,  
 'Binned_MUFA' = cut(samp_dat_wdiv$MUFA, breaks = c(0, 9.795433, 17.000000, Inf), 
  labels = c("Low", "Medium", "High"), include.lowest = TRUE))

Binned_PUFA <- data.frame('PUFA' = samp_dat_wdiv$PUFA, 
 'Binned_PUFA' = cut(samp_dat_wdiv$PUFA, breaks = c(0, 19.59999, 32.50000, Inf), 
  labels = c("Low", "Medium", "High"), include.lowest = TRUE))

rownames(Binned_SFA) <- rownames(samp_dat_wdiv)
rownames(Binned_MUFA) <- rownames(samp_dat_wdiv)
rownames(Binned_PUFA) <- rownames(samp_dat_wdiv)

###load in pd_final.RData to merge it with the binned results###

load("pd_final.RData")

###Merging Binned results###
#Merge the binned results with the samp_dat_wdiv and save it as a new object.

samp_dat_wdiv_Bin <-distinct(left_join(samp_dat_wdiv, Binned_SFA))
samp_dat_wdiv_Bin <-distinct(left_join(samp_dat_wdiv_Bin, Binned_MUFA))
samp_dat_wdiv_Bin <-distinct(left_join(samp_dat_wdiv_Bin, Binned_PUFA))

rownames(samp_dat_wdiv_Bin) <- rownames(samp_dat_wdiv)

#Optional: Relocate the original FA columns to the left hand side of their
#respective binned columns at the end the data frame. Also, move the Shannon to 
#be on the right side of the Fisher Column

samp_dat_wdiv_Bin <- relocate(samp_dat_wdiv_Bin, 'SFA', .before = "Binned_SFA")
samp_dat_wdiv_Bin <- relocate(samp_dat_wdiv_Bin, 'MUFA', .before = "Binned_MUFA")
samp_dat_wdiv_Bin <- relocate(samp_dat_wdiv_Bin, 'PUFA', .before = "Binned_PUFA")
samp_dat_wdiv_Bin <- relocate(samp_dat_wdiv_Bin, 'Shannon', .after = "Fisher")

#Filter samp_dat_wdiv_Bin into two parts, one with PD patient values, and another
#with only control patient values.

samp_dat_wdiv_Bin_PD <- filter(samp_dat_wdiv_Bin, Disease=="PD")
samp_dat_wdiv_Bin_Control <- filter(samp_dat_wdiv_Bin, Disease=="Control")

#Repeat the process above but add the binned columns to the pd_final phyloseq object 
#which will be used for downstream experimental aims (ISA and DESeq). Also,  
#add the Shannon diversity metric to it as well. 

sample_data(pd_final)$Binned_SFA <- c(Binned_SFA$Binned_SFA)
sample_data(pd_final)$Binned_MUFA <- c(Binned_MUFA$Binned_MUFA)
sample_data(pd_final)$Binned_PUFA <- c(Binned_PUFA$Binned_PUFA)
sample_data(pd_final)$Shannon <- c(samp_dat_wdiv$Shannon)

#Optional relocation script, only for aesthetic reasons

sample_data(pd_final) <- relocate(data.frame(sample_data(pd_final)), 'SFA', .before = "Binned_SFA")
sample_data(pd_final) <- relocate(data.frame(sample_data(pd_final)), 'MUFA', .before = "Binned_MUFA")
sample_data(pd_final) <- relocate(data.frame(sample_data(pd_final)), 'PUFA', .before = "Binned_PUFA")
sample_data(pd_final) <- relocate(data.frame(sample_data(pd_final)), 'Shannon', .before = "SFA")

#Separate the merged pd_final phyloseq object into two phyloseq objects, one with 
#only the PD patients and another with only the control patients

pd_final_Bin_PD <- subset_samples(pd_final, Disease=="PD")
pd_final_Bin_Control <- subset_samples(pd_final, Disease=="Control")

###Save samp_dat_wdiv_filt object and the new pd_final phyloseq object###

save(samp_dat_wdiv_Bin_PD, file="samp_dat_wdiv_Bin_PD.RData")
save(samp_dat_wdiv_Bin_Control, file="samp_dat_wdiv_Bin_Control.RData")
save(pd_final_Bin_PD, file="pd_final_Bin_PD.RData")
save(pd_final_Bin_Control, file="pd_final_Bin_Control.RData")
