####load the required packages####

library(phyloseq)
library(ape)
library(tidyverse)
library(vegan)

####loading in metadata, otu table, taxonomy, and phylogenetic tree file####
#load the metadata, otu, and taxonomy files using the read_delim to use tibbles, 
#but not for the phylogenetic tree data

metafp <- "parkinsons_export/parkinsons_metadata.txt"
meta <- read_delim(metafp, delim="\t")

otufp <- "parkinsons_export/table_export/feature-table.txt"
otu <- read_delim(file = otufp, delim="\t", skip=1)

taxfp <- "parkinsons_export/taxonomy_export/taxonomy.tsv"
tax <- read_delim(taxfp, delim="\t")

phylotreefp <- "parkinsons_export/rooted_tree_export/tree.nwk"
phylotree <- read.tree(phylotreefp)

####filtering####
#filter out the any Archaea domain, chloroplast order, and mitochondria family
#in the taxonomy 

tax_fil <- tax %>%
  separate(col=Taxon, sep="; ", into = c("Domain","Phylum","Class","Order","Family","Genus","Species")) %>%
  filter(!Domain == "d__Archaea") %>%
  filter(!Order == "o__Chloroplast") %>%
  filter(!Family == "f__Mitochondria")

####convert object into phyolseq class####
#convert the taxa, metadata, and otu into phyloseq objects and then merge them all
#with the phylotree using phyloseq()

tax_mat <- as.matrix(tax_fil)
tax_mat <- tax_mat[,-1]
rownames(tax_mat) <- tax_fil$'Feature ID'
TAX <- tax_table(tax_mat)
class(TAX)

samp_df <- as.data.frame(meta[,-1])
rownames(samp_df)<- meta$'#SampleID'
SAMP <- sample_data(samp_df)
class(SAMP)

otu_mat <- as.matrix(otu[,-1])
rownames(otu_mat) <- otu$`#OTU ID`
OTU <- otu_table(otu_mat, taxa_are_rows = TRUE)
class(OTU)

pd <- phyloseq(OTU, SAMP, TAX, phylotree)

####Filtering the pd object####
# Removing ASVs that have less than 5 total counts 
pd_nolow_ASV <- filter_taxa(pd, function(x) sum(x)>5, prune = TRUE)
# Remove samples with less than 100 total reads
pd_nolow_ASV_samps <- prune_samples(sample_sums(pd_nolow_ASV)>100, pd_nolow_ASV)
# Remove samples where SFA, MUFA, and PUFA contain NA
pd_final <- subset_samples(pd_nolow_ASV_samps, !is.na(sample_data(pd)$SFA) & !is.na(sample_data(pd)$MUFA) & !is.na(sample_data(pd)$PUFA))

####rarefy the data####
#rarefy the data and create by first creating a rarecurve with a vertical line
#at the chosen sample size

rarecurve(t(as.data.frame(otu_table(pd_final))), cex=0.1) %>%
  abline(v = 3000)
pd_rare <- rarefy_even_depth(pd_final, rngseed = 1, sample.size = 3000)

###save the pd_final and pd_rare####
save(pd_final, file="pd_final.RData")
save(pd_rare, file="pd_rare.RData")

